@@ -3,8 +3,26 @@ use strict;
 
 package RT::Extension::MobileUI;
 
-our $VERSION = "1.01";
+our $VERSION = "1.02";
 
+sub _encode_surrogates {
+    my $uni = $_[0] - 0x10000;
+    return ($uni /  0x400 + 0xD800, $uni % 0x400 + 0xDC00);
+}
+
+sub EscapeJS {
+    my $val = shift;
+    return unless defined $val;
+
+    return "'" . join('',
+                 map {
+                     chr($_) =~ /[a-zA-Z0-9]/ ? chr($_) :
+                     $_  <= 255   ? sprintf("\\x%02X", $_) :
+                     $_  <= 65535 ? sprintf("\\u%04X", $_) :
+                     sprintf("\\u%X\\u%X", _encode_surrogates($_))
+                 } unpack('U*', $val))
+        . "'";
+}
 
 =head1 NAME
 
